@@ -120,8 +120,10 @@ CommandMap cmdMap[] =
   { "_internalref",  CMD_INTERNALREF },
   { "dot",           CMD_DOT },
   { "msc",           CMD_MSC },
+  { "startuml",      CMD_STARTUML },
   { "enddot",        CMD_ENDDOT },
   { "endmsc",        CMD_ENDMSC },
+  { "enduml",        CMD_ENDUML },
   { "manonly",       CMD_MANONLY },
   { "endmanonly",    CMD_ENDMANONLY },
   { "includelineno", CMD_INCWITHLINES },
