@@ -1,8 +1,8 @@
 /*****************************************************************************
  *
- * $Id: commentcnv.l,v 1.80 2001/03/19 19:27:41 root Exp $
+ * 
  *
- * Copyright (C) 1997-2013 by Dimitri van Heesch.
+ * Copyright (C) 1997-2014 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -16,7 +16,7 @@
  */
 
 #ifndef _COMMENTCNV_H
-#define _COMMNETCNV_H
+#define _COMMENTCNV_H
 
 class BufStr;
 
