@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2013 by Dimitri van Heesch.
+ * Copyright (C) 1997-2014 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -271,7 +271,7 @@ class Definition : public DefinitionIntf
     //-----------------------------------------------------------------------------------
 
     /*! Sets a new \a name for the definition */
-    void setName(const char *name);
+    virtual void setName(const char *name);
 
     /*! Sets a unique id for the symbol. Used for libclang integration. */
     void setId(const char *name);
@@ -371,11 +371,9 @@ class DefinitionList : public QList<Definition>, public DefinitionIntf
   public:
     ~DefinitionList() {}
     DefType definitionType() const { return TypeSymbolList; }
-    int compareItems(QCollection::Item item1,QCollection::Item item2)
+    int compareValues(const Definition *item1,const Definition *item2) const
     {
-      return qstricmp(((Definition *)item1)->name(),
-                     ((Definition *)item2)->name()
-                    );
+      return qstricmp(item1->name(),item2->name());
     }
 
 };
