@@ -133,8 +133,13 @@ class Entry
     static const uint64 Enum            = (1ULL<<12); // for Java-style enums
     static const uint64 Service         = (1ULL<<13); // UNO IDL
     static const uint64 Singleton       = (1ULL<<14); // UNO IDL
+    static const uint64 ForwardDecl     = (1ULL<<14); // forward declarad template classes
 
     // member specifiers (add new items to the beginning)
+    static const uint64 PrivateGettable     = (1ULL<<20); // C# private getter
+    static const uint64 ProtectedGettable   = (1ULL<<21); // C# protected getter
+    static const uint64 PrivateSettable     = (1ULL<<22); // C# private setter
+    static const uint64 ProtectedSettable   = (1ULL<<23); // C# protected setter
     static const uint64 Inline          = (1ULL<<24);
     static const uint64 Explicit        = (1ULL<<25);
     static const uint64 Mutable         = (1ULL<<26);
