@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2013 by Dimitri van Heesch.
+ * Copyright (C) 1997-2014 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -27,6 +27,7 @@
 class FortranLanguageScanner : public ParserInterface
 {
   public:
+    FortranLanguageScanner(FortranFormat format=FortranFormat_Unknown) : m_format(format) { }
     virtual ~FortranLanguageScanner() {}
     void startTranslationUnit(const char *) {}
     void finishTranslationUnit() {}
@@ -53,6 +54,21 @@ class FortranLanguageScanner : public ParserInterface
                   );
     void resetCodeParserState();
     void parsePrototype(const char *text);
+
+  private:
+    FortranFormat m_format;
+};
+
+class FortranLanguageScannerFree : public FortranLanguageScanner
+{
+  public:
+    FortranLanguageScannerFree() : FortranLanguageScanner(FortranFormat_Free) { }
+};
+
+class FortranLanguageScannerFixed : public FortranLanguageScanner
+{
+  public:
+    FortranLanguageScannerFixed() : FortranLanguageScanner(FortranFormat_Fixed) { }
 };
 
 #endif
