@@ -32,6 +32,7 @@
 #include "filedef.h"
 #include "config.h"
 #include "htmlentity.h"
+#include "plantuml.h"
 
 static QCString escapeLabelName(const char *s)
 {
@@ -321,6 +322,16 @@ void LatexDocVisitor::visit(DocVerbatim *s)
         if (Config_getBool("DOT_CLEANUP")) file.remove();
       }
       break;
+    case DocVerbatim::PlantUML: 
+      {
+        QCString latexOutput = Config_getString("LATEX_OUTPUT");
+        QCString baseName = writePlantUMLSource(latexOutput,s->exampleFile(),s->text());
+
+        m_t << "\\begin{center}\n";
+        writePlantUMLFile(baseName);
+        m_t << "\\end{center}\n";
+      }
+      break;
   }
 }
 
@@ -809,21 +820,32 @@ void LatexDocVisitor::visitPost(DocHtmlDescData *)
 {
 }
 
+static const char *getTableName(const DocNode *n)
+{
+  bool isNested=FALSE;
+  while (n && !isNested)
+  {
+    isNested = n->kind()==DocNode::Kind_HtmlTable;
+    n  = n->parent();
+  }
+  return isNested ? "TabularNC" : "TabularC";
+}
+
 void LatexDocVisitor::visitPre(DocHtmlTable *t)
 {
   m_rowSpans.clear();
   m_insideTable=TRUE;
   if (m_hide) return;
-  if (t->hasCaption()) 
+  if (t->hasCaption())
   {
     m_t << "\\begin{table}[h]";
   }
-  m_t << "\\begin{TabularC}{" << t->numColumns() << "}\n";
+  m_t << "\\begin{" << getTableName(t->parent()) << "}{" << t->numColumns() << "}\n";
   m_numCols = t->numColumns();
   m_t << "\\hline\n";
 }
 
-void LatexDocVisitor::visitPost(DocHtmlTable *t) 
+void LatexDocVisitor::visitPost(DocHtmlTable *t)
 {
   m_insideTable=FALSE;
   if (m_hide) return;
@@ -833,14 +855,14 @@ void LatexDocVisitor::visitPost(DocHtmlTable *t)
   }
   else
   {
-    m_t << "\\end{TabularC}\n";
+    m_t << "\\end{" << getTableName(t->parent()) << "}\n";
   }
 }
 
-void LatexDocVisitor::visitPre(DocHtmlCaption *)
+void LatexDocVisitor::visitPre(DocHtmlCaption *c)
 {
   if (m_hide) return;
-  m_t << "\\end{TabularC}\n\\centering\n\\caption{";
+  m_t << "\\end{" << getTableName(c->parent()) << "}\n\\centering\n\\caption{";
 }
 
 void LatexDocVisitor::visitPost(DocHtmlCaption *) 
@@ -1587,7 +1609,7 @@ void LatexDocVisitor::startDotFile(const QCString &fileName,
   baseName.prepend("dot_");
   QCString outDir = Config_getString("LATEX_OUTPUT");
   QCString name = fileName;
-  writeDotGraphFromFile(name,outDir,baseName,EPS);
+  writeDotGraphFromFile(name,outDir,baseName,GOF_EPS);
   if (hasCaption)
   {
     m_t << "\n\\begin{DoxyImage}\n";
@@ -1732,6 +1754,7 @@ void LatexDocVisitor::writeMscFile(const QCString &baseName)
   m_t << "\\end{DoxyImageNoCaption}\n";
 }
 
+
 void LatexDocVisitor::startDiaFile(const QCString &fileName,
                                    const QCString &width,
                                    const QCString &height,
@@ -1823,3 +1846,20 @@ void LatexDocVisitor::writeDiaFile(const QCString &baseName)
   m_t << "\\end{DoxyImageNoCaption}\n";
 }
 
+void LatexDocVisitor::writePlantUMLFile(const QCString &baseName)
+{
+  QCString shortName = baseName;
+  int i;
+  if ((i=shortName.findRev('/'))!=-1)
+  {
+    shortName=shortName.right(shortName.length()-i-1);
+  }
+  QCString outDir = Config_getString("LATEX_OUTPUT");
+  generatePlantUMLOutput(baseName,outDir,PUML_EPS);
+  m_t << "\n\\begin{DoxyImageNoCaption}"
+         "  \\mbox{\\includegraphics";
+  m_t << "{" << shortName << "}";
+  m_t << "}\n"; // end mbox
+  m_t << "\\end{DoxyImageNoCaption}\n";
+}
+
