@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2013 by Dimitri van Heesch.
+ * Copyright (C) 1997-2014 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -125,9 +125,10 @@ class MemberGroupSDict : public SIntDict<MemberGroup>
   public:
     MemberGroupSDict(int size=17) : SIntDict<MemberGroup>(size) {}
    ~MemberGroupSDict() {}
-    int compareItems(QCollection::Item item1,QCollection::Item item2)
+ private:
+    int compareValues(const MemberGroup *item1,const MemberGroup *item2) const
     {
-      return ((MemberGroup *)item1)->groupId() - ((MemberGroup*)item2)->groupId();
+      return item1->groupId() - item2->groupId();
     }
 };
 
