@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2013 by Dimitri van Heesch.
+ * Copyright (C) 1997-2014 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -148,17 +148,19 @@ class ParserManager
     ParserManager()
       : m_defaultParser(0) { m_parsers.setAutoDelete(TRUE); }
 
+    void registerDefaultParser(ParserInterface *parser)
+    {
+      m_defaultParser = parser;
+    }
+
     /** Registers an additional parser.
      *  @param[in] name      A symbolic name of the parser, i.e. "c",
      *                       "python", "fortran", "vhdl", ...
      *  @param[in] parser    The parser that is to be used for the
      *                       given name.
-     *  @param[in] defParser Use this parser as the default parser, used
-     *                       for unregistered file extensions.
      */
-    void registerParser(const char *name,ParserInterface *parser,bool defParser=FALSE)
+    void registerParser(const char *name,ParserInterface *parser)
     {
-      if (defParser && m_defaultParser==0) m_defaultParser=parser;
       m_parsers.insert(name,parser);
     }
 
@@ -184,8 +186,8 @@ class ParserManager
      */
     ParserInterface *getParser(const char *extension)
     {
-      if (extension==0) return m_defaultParser;
       QCString ext = QCString(extension).lower();
+      if (ext.isEmpty()) ext=".no_extension";
       ParserInterface *intf = m_extensions.find(ext);
       if (intf==0 && ext.length()>4)
       {
