@@ -33,8 +33,10 @@ class Qhp : public IndexIntf
     void decContentsDepth();
     void addContentsItem(bool isDir, const char * name, const char * ref,
                          const char * file, const char * anchor,
-                         bool separateIndex,bool addToNavIndex);
-    void addIndexItem(Definition *context,MemberDef *md,const char *title);
+                         bool separateIndex,bool addToNavIndex,
+                         Definition *def);
+    void addIndexItem(Definition *context, MemberDef *md,
+                      const char *sectionAnchor, const char *title);
     void addIndexFile(const char * name);
     void addImageFile(const char * name);
     void addStyleSheetFile(const char * name);
@@ -45,7 +47,7 @@ class Qhp : public IndexIntf
   private:
     void handlePrevSection();
     void clearPrevSection();
-    void setPrevSection(const char * title, const char * ref, int level);
+    void setPrevSection(const char * title, const char * basename, const char * anchor, int level);
     void addFile(const char * fileName);
 
     static QCString getFullProjectName();
@@ -56,7 +58,8 @@ class Qhp : public IndexIntf
     QhpXmlWriter m_files;
 
     QCString m_prevSectionTitle;
-    QCString m_prevSectionRef;
+    QCString m_prevSectionBaseName;
+    QCString m_prevSectionAnchor;
 
     int m_prevSectionLevel;
     int m_sectionLevel;
