@@ -1,9 +1,9 @@
 /******************************************************************************
  *
- * $Id: reflist.h,v 1.2 2001/03/19 19:27:41 root Exp $
+ * 
  *
  *
- * Copyright (C) 1997-2013 by Dimitri van Heesch.
+ * Copyright (C) 1997-2014 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -44,10 +44,9 @@ class SortedRefItems : public SDict<RefItem>
   public:
     SortedRefItems(int size=17) : SDict<RefItem>(size) {}
     virtual ~SortedRefItems() {}
-    int compareItems(QCollection::Item item1,QCollection::Item item2)
+  private:
+    int compareValues(const RefItem *r1,const RefItem *r2) const
     {
-      RefItem *r1 = (RefItem*)item1;
-      RefItem *r2 = (RefItem*)item2;
       return qstricmp(r1->title,r2->title);
     }
 };
