@@ -3,7 +3,7 @@
  *
  *
  *
- * Copyright (C) 1997-2013 by Dimitri van Heesch.
+ * Copyright (C) 1997-2014 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby
@@ -21,7 +21,7 @@
 
 /*
  * Danish translation by
- * Erik Se Srensen <eriksoe@daimi.au.dk>
+ * Erik Søe Sørensen <eriksoe@daimi.au.dk>
  *
  * First version (not complete) for Doxygen 1.2.7
  * Extended and revised for Doxygen 1.3
@@ -31,28 +31,28 @@
 
 /*  Translator's notes:
 
-	Oversttelseskonventioner:
+	Oversættelseskonventioner:
 	(Konventioner for konventioner:
-	  '?'    angiver oversttelser, jeg har vret i tvivl om
-	  '??'   angiver tvivlsomme oversttelser
-	  '..?'  angiver ord, der endnu ikke er fundet en oversttelse til
+	  '?'    angiver oversættelser, jeg har været i tvivl om
+	  '??'   angiver tvivlsomme oversættelser
+	  '..?'  angiver ord, der endnu ikke er fundet en oversættelse til
  	  '(do.)' angiver ord, der med vilje ikke er oversat, idet jeg selv
              overvejende bruger det engelske udtryk
-	  '(-> _)' angiver ord, der er fundet en oversttelse til, men som jeg
-	        vgrer mig ved at overstte.
-          'KLID:_' angiver ord, hvor jeg med overlg har rettet mig efter
-		KLID.dk's oversttelsesguide (enig eller ej).
+	  '(-> _)' angiver ord, der er fundet en oversættelse til, men som jeg
+	        vægrer mig ved at oversætte.
+          'KLID:_' angiver ord, hvor jeg med overlæg har rettet mig efter
+		KLID.dk's oversættelsesguide (enig eller ej).
 	)
 	bug -> 'kendt fejl'
 	class -> klasse
 	compound -> 'sammensat type'
-	constructor -> konstruktr ?
-	destructor -> destruktr ?
-	directory -> KLID:katalog (kunne ogs vre 'bibliotek','mappe','folder')
+	constructor -> konstruktør ?
+	destructor -> destruktør ?
+	directory -> KLID:katalog (kunne også være 'bibliotek','mappe','folder')
 	event -> begivenhed ?
 	exception (-> undtagelse ?)
 	friend ..?
-	interface -> grnseflade ?
+	interface -> grænseflade ?
 	member -> medlem (TODO)
 	namespace -> (do.)
 	overloaded -> KLID:overdefineret
@@ -70,13 +70,13 @@
 	union ..?
 
 	Specielle forbindelser:
-	'Inheritance diagram' -> Stamtr  (selvom Nedarvningsdiagram ogs gik an)
-        
+	'Inheritance diagram' -> Stamtræ  (selvom Nedarvningsdiagram også gik an)
+
 
 	-----
 
-	(Konstruktivt) input modtages med glde!
-	-- Erik Se Srensen <eriksoe@daimi.au.dk>
+	(Konstruktivt) input modtages med glæde!
+	-- Erik Søe Sørensen <eriksoe@daimi.au.dk>
 
 
 	links -> (links.)
@@ -120,12 +120,6 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
 	"\\usepackage[T1]{fontenc}\n";
     }
 
-    /*! return the language charset. This will be used for the HTML output */
-    virtual QCString idLanguageCharset()
-    {
-      return "iso-8859-1";
-    }
-
     // --- Language translation methods -------------------
 
     /*! used in the compound documentation before a list of related functions. */
@@ -134,7 +128,7 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
 
     /*! subscript for the related functions. */
     virtual QCString trRelatedSubscript()
-    { return "(Bemrk at disse ikke er medlems-funktioner.)"; }
+    { return "(Bemærk at disse ikke er medlems-funktioner.)"; }
 
     /*! header that is put before the detailed description of files,
 	 * classes and namespaces. */
@@ -200,7 +194,7 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
 
     /*! put after an enum value in the list of all members */
     virtual QCString trEnumValue()
-    { return "enumerationsvrdi"; }
+    { return "enumerationsværdi"; }
 
     /*! put after an undocumented member in the list of all members */
     virtual QCString trDefinedIn()
@@ -263,12 +257,12 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
 
     /*! This is put above each page as a link to the search engine. */
     virtual QCString trSearch()
-    { return "Sg"; }
+    { return "Søg"; }
 
     /*! This is an introduction to the class hierarchy. */
     virtual QCString trClassHierarchyDescription()
-    { return "Denne nedarvningsliste er sorteret nsten - "
-             "men ikke ndvendigvis helt - alfabetisk:";
+    { return "Denne nedarvningsliste er sorteret næsten - "
+             "men ikke nødvendigvis helt - alfabetisk:";
     }
 
     /*! This is an introduction to the list with all files. */
@@ -288,7 +282,7 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
         return "Her er datastrukturerne med korte beskrivelser:";
       } else {
         return "Her er klasserne, datastrukturerne, "
-               "unionerne og grnsefladerne med korte beskrivelser:";
+               "unionerne og grænsefladerne med korte beskrivelser:";
       }
     }
 
@@ -313,9 +307,9 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
         }
       } else {
         if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C")) {
-          result+="de datastrukturer/unioner, de hrer til:";
+          result+="de datastrukturer/unioner, de hører til:";
         } else {
-          result+="de klasser, de hrer til:";
+          result+="de klasser, de hører til:";
         }
       }
       return result;
@@ -335,7 +329,7 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
       }
       result+=", med links til ";
       if (extractAll)
-        result+="de filer, de tilhrer:";
+        result+="de filer, de tilhører:";
       else
         result+="deres dokumentation:";
       return result;
@@ -433,12 +427,6 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
     virtual QCString trDefines()
     { return "#Defines"; }
 
-    /*! This is used in the documentation of a file as a header before the
-     *  list of function prototypes
-     */
-    virtual QCString trFuncProtos()
-    { return "Funktionsprototyper"; }
-
     /*! This is used in the documentation of a file as a header before the
      *  list of typedefs
      */
@@ -467,7 +455,7 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
      *  list of (global) variables
      */
     virtual QCString trEnumerationValues()
-    { return "Enumerationsvrdier"; }
+    { return "Enumerationsværdier"; }
 
     /*! This is used in the documentation of a file before the list of
      *  documentation blocks for defines
@@ -475,12 +463,6 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
     virtual QCString trDefineDocumentation()
     { return "#Define-dokumentation"; }
 
-    /*! This is used in the documentation of a file/namespace before the list
-     *  of documentation blocks for function prototypes
-     */
-    virtual QCString trFunctionPrototypeDocumentation()
-    { return "Dokumentation af funktionsprototyper"; }
-
     /*! This is used in the documentation of a file/namespace before the list
      *  of documentation blocks for typedefs
      */
@@ -497,7 +479,7 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
      *  of documentation blocks for enumeration values
      */
     virtual QCString trEnumerationValueDocumentation()
-    { return "Dokumentation af enumerations-vrdier"; }
+    { return "Dokumentation af enumerations-værdier"; }
 
     /*! This is used in the documentation of a file/namespace before the list
      *  of documentation blocks for functions
@@ -533,15 +515,11 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
       result+=(QCString)" af";
       return result;
     }
-    /*! This is part of the sentence used in the standard footer of each page.
-     */
-    virtual QCString trWrittenBy()
-    { return "skrevet af"; }
 
     /*! this text is put before a class diagram */
     virtual QCString trClassDiagram(const char *clName)
     {
-      return (QCString)"Stamtr for "+clName+":";
+      return (QCString)"Stamtræ for "+clName+":";
     }
 
     /*! this text is generated when the \\internal command is used. */
@@ -566,7 +544,7 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
 
     /*! this text is generated when the \\sa command is used. */
     virtual QCString trSeeAlso()
-    { return "Se ogs"; }
+    { return "Se også"; }
 
     /*! this text is generated when the \\param command is used. */
     virtual QCString trParameters()
@@ -628,7 +606,7 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
         case ClassDef::Class:      result+=" Klasse-"; break;
         case ClassDef::Struct:     result+=" Datastruktur-"; break;
         case ClassDef::Union:      result+=" Union-"; break;
-        case ClassDef::Interface:  result+=" Grnseflade-"; break;
+        case ClassDef::Interface:  result+=" Grænseflade-"; break;
         case ClassDef::Protocol:   result+=" Protokol-"; break;
         case ClassDef::Category:   result+=" Kategori-"; break; // " Category-"
         case ClassDef::Exception:  result+=" Undtagelse-"; break;   //  " Exception"
@@ -744,7 +722,7 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
       if (extractAll)
         result+="namespace-dokumentationen for hvert medlem:";
       else
-        result+="det namespace, de hrer til:";
+        result+="det namespace, de hører til:";
       return result;
     }
     /*! This is used in LaTeX as the title of the chapter with the
@@ -786,7 +764,7 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
         case ClassDef::Class:      result+="klasse"; break;
         case ClassDef::Struct:     result+="datastruktur"; break;
         case ClassDef::Union:      result+="union"; break;
-        case ClassDef::Interface:  result+="grnseflade"; break;
+        case ClassDef::Interface:  result+="grænseflade"; break;
         case ClassDef::Protocol:   result+="protokol"; break; // "protocol"
         case ClassDef::Category:   result+="kategori"; break; // "category"
         case ClassDef::Exception:  result+="undtagelse"; break;  // "exception"
@@ -797,19 +775,13 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
       return result;
     }
 
-    /*! This is in the (quick) index as a link to the alphabetical compound
-     * list.
-     */
-    virtual QCString trAlphabeticalList()
-    { return "Alfabetisk oversigt"; }
-
 //////////////////////////////////////////////////////////////////////////
 // new since 0.49-990901
 //////////////////////////////////////////////////////////////////////////
 
     /*! This is used as the heading text for the retval command. */
     virtual QCString trReturnValues()
-    { return "Returvrdier"; }
+    { return "Returværdier"; }
 
     /*! This is in the (quick) index as a link to the main page (index.html)
      */
@@ -828,7 +800,7 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
 
     virtual QCString trDefinedAtLineInSourceFile()
     {
-      return "Defineret p linje @0 i filen @1.";
+      return "Defineret på linje @0 i filen @1.";
     }
 
     virtual QCString trDefinedInSourceFile()
@@ -842,7 +814,7 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
 
     virtual QCString trDeprecated()
     {
-      return "Frardes - fortidslevn"; // ?? - What is the context?
+      return "Frarådes - fortidslevn"; // ?? - What is the context?
 	  // "Ugleset" :)
     }
 
@@ -858,12 +830,12 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
     /*! this text is put before an include dependency graph */
     virtual QCString trInclDepGraph(const char *fName)
     {
-      return (QCString)"Inklusions-afhngighedsgraf for "+fName+":";
+      return (QCString)"Inklusions-afhængighedsgraf for "+fName+":";
     }
     /*! header that is put before the list of constructor/destructors. */
     virtual QCString trConstructorDocumentation()
     {
-      return "Dokumentation af konstruktrer og destruktrer";
+      return "Dokumentation af konstruktører og destruktører";
       // "Constructor & Destructor dokumentation";
     }
 
@@ -876,7 +848,7 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
 
     /*! Text for the \\pre command */
     virtual QCString trPrecondition()
-    { return "Forudstninger (precondition)"; }
+    { return "Forudsætninger (precondition)"; }
     /*! Text for the \\post command */
     virtual QCString trPostcondition()
     { return "Resultat (postcondition)"; }
@@ -886,7 +858,7 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
 
     /*! Text shown before a multi-line variable/enum initialization */
     virtual QCString trInitialValue()
-    { return "Startvrdi:"; }
+    { return "Startværdi:"; }
 
     /*! Text used the source code in the file index */
     virtual QCString trCode()
@@ -958,7 +930,7 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
     }
     virtual QCString trRemarks()
     {
-      return "Bemrkninger";
+      return "Bemærkninger";
     }
     virtual QCString trAttention()
     {
@@ -990,11 +962,11 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
       return
 		"Denne side forklarer, hvordan man skal fortolke de grafer, "
 		"der genereres af doxygen.<p>\n"
-        "Tag flgende eksempel:\n"
+        "Tag følgende eksempel:\n"
         "\\code\n"
-        "/*! Klasse der er usynlig pg.a. beskring */\n"
+        "/*! Klasse der er usynlig pg.a. beskæring */\n"
         "class Invisible { };\n\n"
-        "/*! Beskret klasse: nedarvningsrelation er skjult */\n"
+        "/*! Beskåret klasse: nedarvningsrelation er skjult */\n"
         "class Truncated : public Invisible { };\n\n"
         "/* Klasse der ikke er dokumenteret med doxygen-kommentarer */\n"
         "class Undocumented { };\n\n"
@@ -1020,36 +992,36 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
         "};\n"
         "\\endcode\n"
         "Hvis \\c MAX_DOT_GRAPH_HEIGHT i konfigurationsfilen "
-        "er sat til 240, vil dette resultere i flgende graf:"
+        "er sat til 240, vil dette resultere i følgende graf:"
         "<p><center><img src=\"graph_legend."+Config_getEnum("DOT_IMAGE_FORMAT")+"\"></center>\n"
         "<p>\n"
-        "De forskellige slags kasser i ovenstende graf har flgende "
+        "De forskellige slags kasser i ovenstående graf har følgende "
 		"betydninger:\n"
         "<ul>\n"
-        "<li>%En udfyldt sort kasse reprsenterer den datastruktur eller "
+        "<li>%En udfyldt sort kasse repræsenterer den datastruktur eller "
 		"klasse, grafen er genereret for.\n"
         "<li>%En kasse med sort kant betegner en dokumenteret datastruktur "
 		" eller klasse.\n"
-        "<li>%En kasse med gr kant betegner en udokumenteret datastruktur "
+        "<li>%En kasse med grå kant betegner en udokumenteret datastruktur "
  		" eller klasse.\n"
-        "<li>%En kasse med rd kant betegner en dokumenteret datastruktur "
+        "<li>%En kasse med rød kant betegner en dokumenteret datastruktur "
  		" eller klasse, for hvilken ikke alle "
 		"nedarvnings- og indeholdelses-relationer er vist. "
-        "%Grafer beskres, hvis de fylder mere end de specificerede dimensioner.\n "
+        "%Grafer beskæres, hvis de fylder mere end de specificerede dimensioner.\n "
         "</ul>\n"
-        "Pilene har flgende betydninger:\n"
+        "Pilene har følgende betydninger:\n"
         "<ul>\n"
-        "<li>%En mrkebl pil viser en offentlig nedarvningsrelation "
+        "<li>%En mørkeblå pil viser en offentlig nedarvningsrelation "
 		"mellem to klasser.\n"
-        "<li>%En mrkegrn pil viser en beskyttet nedarvningsrelation.\n"
-        "<li>%En mrkerd pil viser en privat nedarvningsrelation.\n"
-        "<li>%En lilla, stiplet pil bruges, nr en klasse er indeholdt i "
+        "<li>%En mørkegrøn pil viser en beskyttet nedarvningsrelation.\n"
+        "<li>%En mørkerød pil viser en privat nedarvningsrelation.\n"
+        "<li>%En lilla, stiplet pil bruges, når en klasse er indeholdt i "
 		"eller benyttes af en anden klasse. "
-        "Ved pilen str navnet p den eller de variable, gennem hvilke(n) "
-		"den klasse, pilen peger p, er tilgngelig.\n"
+        "Ved pilen står navnet på den eller de variable, gennem hvilke(n) "
+		"den klasse, pilen peger på, er tilgængelig.\n"
         "<li>%En gul, stiplet pil viser forholdet mellem en template-instans "
 		"og den template-klasse, den er instantieret fra."
-        "Ved pilen str template-parametrene brugt ved instantieringen.\n"
+        "Ved pilen står template-parametrene brugt ved instantieringen.\n"
         "</ul>\n";
     }
     /*! text for the link to the legend page */
@@ -1073,16 +1045,6 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
       return "Testliste";
     }
 
-//////////////////////////////////////////////////////////////////////////
-// new since 1.2.1
-//////////////////////////////////////////////////////////////////////////
-
-    /*! Used as a section header for KDE-2 IDL methods */
-    virtual QCString trDCOPMethods()
-    {
-      return "DCOP-metoder";
-    }
-
 //////////////////////////////////////////////////////////////////////////
 // new since 1.2.2
 //////////////////////////////////////////////////////////////////////////
@@ -1126,7 +1088,7 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
     {
       return
 	"Her er en liste over pakkerne, med korte beskrivelser "
-	"(hvor en sdan findes):";
+	"(hvor en sådan findes):";
     }
     /*! The link name in the Quick links header for each page */
     virtual QCString trPackages()
@@ -1136,7 +1098,7 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
     /*! Text shown before a multi-line define */
     virtual QCString trDefineValue()
     {
-      return "Vrdi:";
+      return "Værdi:";
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1309,7 +1271,7 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
      */
     virtual QCString trDeprecatedList()
     {
-      return "Liste over fortidslevn, hvis brug frardes";
+      return "Liste over fortidslevn, hvis brug frarådes";
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1367,21 +1329,12 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
 // new since 1.3.3
 //////////////////////////////////////////////////////////////////////////
 
-    /*! When the search engine is enabled this text is put in the header
-     *  of each page before the field where one can enter the text to search
-     *  for.
-     */
-    virtual QCString trSearchForIndex()
-    {
-      return "Sg efter";
-    }
-
     /*! This string is used as the title for the page listing the search
      *  results.
      */
     virtual QCString trSearchResultsTitle()
     {
-      return "Sgeresultater";
+      return "Søgeresultater";
     }
 
     /*! This string is put just before listing the search results. The
@@ -1395,13 +1348,13 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
     virtual QCString trSearchResults(int numDocuments)
     {
       if (numDocuments==0) {
-        return "Beklager - ingen dokumenter passede til din foresprgsel.";
+        return "Beklager - ingen dokumenter passede til din forespørgsel.";
       } else if (numDocuments==1) {
-        return "Fandt <b>1</b> dokument, der passer til din foresprgsel.";
+        return "Fandt <b>1</b> dokument, der passer til din forespørgsel.";
       } else {
         return
-	  "Fandt <b>$num</b> dokumenter, der passer til din foresprgsel. "
-	  "De, der passer bedst, vises frst.";
+	  "Fandt <b>$num</b> dokumenter, der passer til din forespørgsel. "
+	  "De, der passer bedst, vises først.";
       }
     }
 
@@ -1448,12 +1401,12 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
     virtual QCString trDirectories()
     { return "Kataloger"; }
 
-    /*! This returns a sentences that introduces the directory hierarchy. 
+    /*! This returns a sentences that introduces the directory hierarchy.
      *  and the fact that it is sorted alphabetically per level
      */
     virtual QCString trDirDescription()
-    { return "Denne katalogstruktur er sorteret nsten - "
-             "men ikke ndvendigvis helt - alfabetisk:";
+    { return "Denne katalogstruktur er sorteret næsten - "
+             "men ikke nødvendigvis helt - alfabetisk:";
     }
 
     /*! This returns the title of a directory page. The name of the
@@ -1466,7 +1419,7 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
      *  (\a first_capital) and in sigular or plural form (\a singular).
      */
     virtual QCString trDir(bool first_capital, bool singular)
-    { 
+    {
       return createNoun(first_capital, singular, "katalog", "er");
     }
 
@@ -1481,7 +1434,7 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
     {
        return "Dette er en overdefineret medlemsfunktion, "
               "defineret af bekvemmelighedshensyn. "
-	      "Den adskiller sig kun fra den ovenstende funktion i, "
+	      "Den adskiller sig kun fra den ovenstående funktion i, "
 	      "hvilke argumenter den tager.";
     }
 
@@ -1502,7 +1455,7 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
     virtual QCString trMemberFunctionDocumentationFortran()
     { return "Medlem Funktion/Subroutine Dokumentation"; }  // "Member Function/Subroutine Documentation"
 
-    /*! This is used in the documentation of a file/namespace before the list 
+    /*! This is used in the documentation of a file/namespace before the list
      *  of documentation blocks for enumeration values
      */
     /*
@@ -1543,7 +1496,7 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
       }
       else
       {
-         result+="de datatyper som de tilhrer:";  // "the data types they belong to:"
+         result+="de datatyper som de tilhører:";  // "the data types they belong to:"
       }
       return result;
     }
@@ -1602,7 +1555,7 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
         case ClassDef::Class:      result+=" Modul"; break;     // " Module"
         case ClassDef::Struct:     result+=" Type"; break;      // " Type"
         case ClassDef::Union:      result+=" Union"; break;     // " Union"
-        case ClassDef::Interface:  result+=" Grnseflade"; break; // " Interface"
+        case ClassDef::Interface:  result+=" Grænseflade"; break; // " Interface"
         case ClassDef::Protocol:   result+=" Protocol"; break;      // " Protocol"
         case ClassDef::Category:   result+=" Kategori"; break;      // " Category"
         case ClassDef::Exception:  result+=" Undtagelse"; break; // " Exception"
@@ -1637,7 +1590,7 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
       }
       else
       {
-        result+="moduler de tilhre:";  // "the modules they belong to:"
+        result+="moduler de tilhøre:";  // "the modules they belong to:"
       }
       return result;
     }
@@ -1672,13 +1625,13 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
         case ClassDef::Class:      result+="modul"; break;        // "module"
         case ClassDef::Struct:     result+="type"; break;         // "type"
         case ClassDef::Union:      result+="union"; break;        // "union"
-        case ClassDef::Interface:  result+="grnseflade"; break;  // "interface"
+        case ClassDef::Interface:  result+="grænseflade"; break;  // "interface"
         case ClassDef::Protocol:   result+="protokol"; break;     // "protocol"
         case ClassDef::Category:   result+="kategori"; break;     // "category"
         case ClassDef::Exception:  result+="undtagelse"; break;   // "exception"
         default: break;
       }
-      result+=" var lavet udfra flgende file";                   // " was generated from the following file"
+      result+=" var lavet udfra følgende file";                   // " was generated from the following file"
       if (single) result+=":"; else result+="r:";                 // ":" / "s:"
       return result;
     }
@@ -1708,7 +1661,7 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
     /*! C# Type Constraint list */
     virtual QCString trTypeConstraints()
     {
-      return "typebegrnsninger";        // "Type Constraints"
+      return "typebegrænsninger";        // "Type Constraints"
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1724,7 +1677,7 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
     /*! Loading message shown when loading search results */
     virtual QCString trLoading()
     {
-      return "Indlser...";          // "Loading..."
+      return "Indlæser...";          // "Loading..."
     }
 
     /*! Label used for search results in the global namespace */
@@ -1736,7 +1689,7 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
     /*! Message shown while searching */
     virtual QCString trSearching()
     {
-      return "Sger...";    // "Searching..."
+      return "Søger...";    // "Searching..."
     }
 
     /*! Text shown when no search results are found */
@@ -1749,12 +1702,6 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
 // new since 1.6.3 (missing items for the directory pages)
 //////////////////////////////////////////////////////////////////////////
 
-    /*! introduction text for the directory dependency graph */
-    virtual QCString trDirDependency(const char *name)
-    {
-      return (QCString)"Afhngighedsgraf for "+name;  // "Directory dependency graph for "
-    }
-
     /*! when clicking a directory dependency label, a page with a
      *  table is shown. The heading for the first column mentions the
      *  source file that has a relation to another file.
@@ -1787,7 +1734,7 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
                                 int hour,int minutes,int seconds,
                                 bool includeTime)
     {
-      static const char *days[]   = { "Man","Tir","Ons","Tor","Fre","Lr","Sn" }; // { "Mon","Tue","Wed","Thu","Fri","Sat","Sun" };
+      static const char *days[]   = { "Man","Tir","Ons","Tor","Fre","Lør","Søn" }; // { "Mon","Tue","Wed","Thu","Fri","Sat","Sun" };
       static const char *months[] = { "Jan","Feb","Mar","Apr","Maj","Jun","Jul","Aug","Sep","Okt","Nov","Dec" };    //  { "Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec" };
       QCString sdate;
       sdate.sprintf("%s %s %d %d",days[dayOfWeek-1],months[month-1],day,year);
@@ -1806,7 +1753,7 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
 
     virtual QCString trCiteReferences()
     {
-      return "Bibliografiske referencer"; 
+      return "Bibliografiske referencer";
     }
 
     virtual QCString trCopyright()
@@ -1816,7 +1763,7 @@ class TranslatorDanish : public TranslatorAdapter_1_8_0
 
     virtual QCString trDirDepGraph(const char *name)
     {
-      return QCString("Afhngighedsgraf for katalog ")+name+":"; 
+      return QCString("Afhængighedsgraf for katalog ")+name+":";
     }
 
 
