@@ -2,7 +2,7 @@
  *
  *
  *
- * Copyright (C) 1997-2013 by Dimitri van Heesch.
+ * Copyright (C) 1997-2014 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby
@@ -43,12 +43,6 @@ class TranslatorSlovak : public Translator
     virtual QCString latexLanguageSupportCommand()
     { return "\\usepackage[slovak]{babel}\n"; }
 
-    /*! return the language charset. This will be used for the HTML output */
-    virtual QCString idLanguageCharset()
-    {
-        return "utf-8";
-    }
-
     // --- Language translation methods -------------------
 
     /*! used in the compound documentation before a list of related functions. */
@@ -396,12 +390,6 @@ class TranslatorSlovak : public Translator
     virtual QCString trDefines()
     { return "Definícia makier"; }
 
-    /*! This is used in the documentation of a file as a header before the
-     *	list of function prototypes
-     */
-    virtual QCString trFuncProtos()
-    { return "Prototypy"; }
-
     /*! This is used in the documentation of a file as a header before the
      *	list of typedefs
      */
@@ -438,12 +426,6 @@ class TranslatorSlovak : public Translator
     virtual QCString trDefineDocumentation()
     { return "Dokumentácia k definíciám makier"; }
 
-    /*! This is used in the documentation of a file/namespace before the list
-     *	of documentation blocks for function prototypes
-     */
-    virtual QCString trFunctionPrototypeDocumentation()
-    { return "Dokumentácia prototypov"; }
-
     /*! This is used in the documentation of a file/namespace before the list
      *	of documentation blocks for typedefs
      */
@@ -494,13 +476,6 @@ class TranslatorSlovak : public Translator
       return result;
     }
 
-    /*! This is part of the sentence used in the standard footer of each page.
-     */
-    virtual QCString trWrittenBy()
-    {
-      return " -- autor ";
-    }
-
     /*! this text is put before a class diagram */
     virtual QCString trClassDiagram(const char *clName)
     {
@@ -775,12 +750,6 @@ class TranslatorSlovak : public Translator
       return result;
     }
 
-    /*! This is in the (quick) index as a link to the alphabetical compound
-     * list.
-     */
-    virtual QCString trAlphabeticalList()
-    { return "Register tried"; }
-
 //////////////////////////////////////////////////////////////////////////
 // new since 0.49-990901
 //////////////////////////////////////////////////////////////////////////
@@ -1087,16 +1056,6 @@ class TranslatorSlovak : public Translator
       return "Zoznam testov";
     }
 
-//////////////////////////////////////////////////////////////////////////
-// new since 1.2.1
-//////////////////////////////////////////////////////////////////////////
-
-    /*! Used as a section header for KDE-2 IDL methods */
-    virtual QCString trDCOPMethods()
-    {
-      return "Metódy DCOP";
-    }
-
 //////////////////////////////////////////////////////////////////////////
 // new since 1.2.2
 //////////////////////////////////////////////////////////////////////////
@@ -1407,13 +1366,6 @@ class TranslatorSlovak : public Translator
 // new since 1.3.3
 //////////////////////////////////////////////////////////////////////////
 
-    /*! When the search engine is enabled this text is put in the index
-     *  of each page before the search field.
-     */
-    virtual QCString trSearchForIndex()
-    {
-      return "Vyhľadať";
-    }
     /*! This string is used as the title for the page listing the search
      *  results.
      */
@@ -1788,12 +1740,6 @@ class TranslatorSlovak : public Translator
 // new since 1.6.3 (missing items for the directory pages)
 //////////////////////////////////////////////////////////////////////////
 
-    /*! introduction text for the directory dependency graph */
-    virtual QCString trDirDependency(const char *name)
-    {
-      return (QCString)"Graf závislosti adresárov pre "+name;
-    }
-
     /*! when clicking a directory dependency label, a page with a
      *  table is shown. The heading for the first column mentions the
      *  source file that has a relation to another file.
